import dataclasses

import datetime
from enum import Enum
from typing import NewType

ETag = NewType('ETag', str)


class StorageClass(str, Enum):
    """
    AWS S3 Storage classes

    https://docs.aws.amazon.com/AmazonS3/latest/dev/storage-class-intro.html
    """

    STANDARD = 'STANDARD'
    REDUCED_REDUNDANCY = 'REDUCED_REDUNDANCY'
    INTELLIGENT_TIERING = 'INTELLIGENT_TIERING'
    STANDARD_IA = 'STANDARD_IA'
    ONEZONE_IA = 'ONEZONE_IA'

    GLACIER = 'GLACIER'
    DEEP_ARCHIVE = 'DEEP_ARCHIVE'


@dataclasses.dataclass(frozen=True)
class Key:
    key: str
    last_modified: datetime
    e_tag: ETag
    size: int
    storage_class: StorageClass

    @property
    def is_pseudo_directory(self):
        return self.key.endswith('/') and self.size == 0



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="sthree",
    version="0.1.0",
    author="Anatoly Scherbakov",
    author_email="altaisoft@gmail.com",
    description=(
        "A suite of typed data structures backed by Amazon S3."
    ),
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://github.com/anatoly-scherbakov/sthree',
    packages=setuptools.find_packages(exclude=[
        'tests',
        'run.py'
    ]),
    install_requires=[
        'boto3_type_annotations'
    ],
    extras_require={
        'boto': [
            'boto3'
        ],
        'dev': [
            'pytest',
            'boto3',
            'moto',
            'fire',
            'twine'
        ]
    },
    license='MIT',
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
